pub struct SeqEncoder<'a, W> { /* private fields */ }Expand description
An encoder used to encode the values in a sequence.
Note that this type cannot be constructed from outside this crate, and is only public because of the way the library’s serialization is implemented.